@@ -3,11 +3,11 @@
 #' Create a checkbox that can be used to specify logical values.
 #'
 #' @inheritParams textInput
-#' @param value Initial value (\code{TRUE} or \code{FALSE}).
+#' @param value Initial value (`TRUE` or `FALSE`).
 #' @return A checkbox control that can be added to a UI definition.
 #'
 #' @family input elements
-#' @seealso \code{\link{checkboxGroupInput}}, \code{\link{updateCheckboxInput}}
+#' @seealso [checkboxGroupInput()], [updateCheckboxInput()]
 #'
 #' @examples
 #' ## Only run examples in interactive R sessions
@@ -22,6 +22,10 @@
 #' }
 #' shinyApp(ui, server)
 #' }
+#'
+#' @section Server value:
+#' `TRUE` if checked, `FALSE` otherwise.
+#'
 #' @export
 checkboxInput <- function(inputId, label, value = FALSE, width = NULL) {
 
@@ -32,7 +36,7 @@ checkboxInput <- function(inputId, label, value = FALSE, width = NULL) {
     inputTag$attribs$checked <- "checked"
 
   div(class = "form-group shiny-input-container",
-    style = if (!is.null(width)) paste0("width: ", validateCssUnit(width), ";"),
+    style = css(width = validateCssUnit(width)),
     div(class = "checkbox",
       tags$label(inputTag, tags$span(label))
     )
